==> haskell-hie-bios-0.12.0-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-57MIubGxvzh8WoK4dCBAm6
key:                  hie-bios-0.12.0-57MIubGxvzh8WoK4dCBAm6
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  3b9b390baf51b4f9c84e03badea6454b
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-57MIubGxvzh8WoK4dCBAm6
depends:
    aeson-2.1.2.1-Kx5U0b11hXDAcrJPuBeHuf base-4.17.2.1
    base16-bytestring-1.0.2.0-KXYtISPPGuc1jDx46dDwiE
    bytestring-0.11.5.3 co-log-core-0.3.2.5-JN8HtDt9oeQ4vsTiNmf9QT
    conduit-1.3.6.1-3OoOkivWqZS7dcQwoEFiHk
    conduit-extra-1.3.8-BJDq9IUY40K5dXgPcvjS82
    cryptohash-sha1-0.11.101.0-Jzjg3pgPRsDJw985tBCSMU deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-5tezMKqv9GA6gNR4q67AdR
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    ghc-9.4.8 prettyprinter-1.7.1-KzM58U4JCdzBv7NnMyEr6Q
    template-haskell-2.19.0.0 temporary-1.3-4U3e01RislmEUeJgFruRX5
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unix-compat-0.7.4.1-7wl3VN2bkjVLyACPiFBxN
    unordered-containers-0.2.20-Jnp6Xrk1NDm4qrPXFyeyaF
    yaml-0.11.11.2-BHSVNcT17WuHrMTwAaUYup

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hie-bios-0.12.0-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-I1f7zq83F1L1ixYGi3RJWQ
key:                  hie-bios-0.12.0-I1f7zq83F1L1ixYGi3RJWQ
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  4da4b98eb3fcd7b95f1bbc02f7139efa
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-I1f7zq83F1L1ixYGi3RJWQ
depends:
    aeson-2.1.2.1-DAjCoZEGWBTDXHPn96Kb1j base-4.17.2.1
    base16-bytestring-1.0.2.0-H62yvQKnYXI2vVR0tnIhus
    bytestring-0.11.5.3 co-log-core-0.3.2.5-IVc4JLhleBcKoxv5Dw511h
    conduit-1.3.6.1-LOP5sjciwZZGtwvmGKv7ZW
    conduit-extra-1.3.8-1JMiFOCwvslD8QGjqNo8o8
    cryptohash-sha1-0.11.101.0-GbMG3jPYjJVCT11ph3EdfF deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-JyTxBhiayTkLmgcKeg6bhV
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    ghc-9.4.8 prettyprinter-1.7.1-CSlGZoOoBlWC7jpjoL7RBV
    template-haskell-2.19.0.0 temporary-1.3-9g1OGPiytt1BO3oUGnOgqn
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unix-compat-0.7.4.1-9t2FupNpdHvF9CotjWq7e6
    unordered-containers-0.2.20-C5ENqrDu1w64CLikkGEoYH
    yaml-0.11.11.2-G90lzws7ieR6hOxChJvZJC

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
